==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/ListVendorSkusCredentialPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property skuName The name of the sku.
 * @property vendorName The name of the vendor.
 */
public data class ListVendorSkusCredentialPlainArgs(
    public val skuName: String,
    public val vendorName: String,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs.builder()
            .skuName(skuName.let({ args0 -> args0 }))
            .vendorName(vendorName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListVendorSkusCredentialPlainArgs].
 */
@PulumiTagMarker
public class ListVendorSkusCredentialPlainArgsBuilder internal constructor() {
    private var skuName: String? = null

    private var vendorName: String? = null

    /**
     * @param value The name of the sku.
     */
    @JvmName("dihkngncbtosgttx")
    public suspend fun skuName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.skuName = mapped
    }

    /**
     * @param value The name of the vendor.
     */
    @JvmName("rfeiqjslxoghgiwm")
    public suspend fun vendorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vendorName = mapped
    }

    internal fun build(): ListVendorSkusCredentialPlainArgs = ListVendorSkusCredentialPlainArgs(
        skuName = skuName ?: throw PulumiNullFieldException("skuName"),
        vendorName = vendorName ?: throw PulumiNullFieldException("vendorName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/ListVendorSkusCredentialPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property skuName The name of the sku.
 * @property vendorName The name of the vendor.
 */
public data class ListVendorSkusCredentialPlainArgs(
    public val skuName: String,
    public val vendorName: String,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.ListVendorSkusCredentialPlainArgs.builder()
            .skuName(skuName.let({ args0 -> args0 }))
            .vendorName(vendorName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListVendorSkusCredentialPlainArgs].
 */
@PulumiTagMarker
public class ListVendorSkusCredentialPlainArgsBuilder internal constructor() {
    private var skuName: String? = null

    private var vendorName: String? = null

    /**
     * @param value The name of the sku.
     */
    @JvmName("htcxhaoaxfovnnft")
    public suspend fun skuName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.skuName = mapped
    }

    /**
     * @param value The name of the vendor.
     */
    @JvmName("ktoyptkthogktwow")
    public suspend fun vendorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vendorName = mapped
    }

    internal fun build(): ListVendorSkusCredentialPlainArgs = ListVendorSkusCredentialPlainArgs(
        skuName = skuName ?: throw PulumiNullFieldException("skuName"),
        vendorName = vendorName ?: throw PulumiNullFieldException("vendorName"),
    )
}
